CREATE OR REPLACE PROCEDURE "SP_EGT_PRE_VALIDACAO"(v_Num_Remessa integer,
                                                   v_Lote        integer) is

  /*
  Autor     : Celio Mansini - 24/10/2011
  Objetivo  : Verificar inconsistencias da remessa gerada
  BUG 269: Itens para verificao, ao final da gerao das remessas:
      1) itens com Desembargadores sendo informados;
      2) itens com juiz nulo (quando necessrio);
      3) dados de Cordeiro e Barra Mansa;
      4) Nmeros de processos invlidos.
  */

  cursor cDesembargadores1 is
    select *
      from EGT_INFO_PROCESSO proc
     inner join egt_pessoa p
        on p.num_pessoa = proc.num_juiz
     where proc.num_remessa = v_Num_Remessa
       and proc.num_lote = v_Lote
       and proc.num_juiz in
           (select tjp.num_pessoa
              from tr_juiz_pessoa tjp             where tjp.sq_juiz in
                   (select j.sq_juiz
                      from tb_juiz j
                     where j.in_desembargador <> 'N'));

  cursor cDesembargadores2 is
    select *
      from EGT_INFO_AUDIENCIA aud
     inner join egt_pessoa p
        on p.num_pessoa = aud.num_juiz
     where aud.num_remessa = v_Num_Remessa
       and aud.num_lote = v_Lote
       and aud.num_juiz in
           (select tjp.num_pessoa
              from tr_juiz_pessoa tjp
             where tjp.sq_juiz in
                   (select j.sq_juiz
                      from tb_juiz j
                     where j.in_desembargador <> 'N'));

  cursor cDesembargadores3 is
    select *
      from EGT_INFO_PESSOA p
     where p.num_remessa = v_Num_Remessa
       and p.num_lote = v_Lote
       and p.num_pessoa in
           (select tjp.num_pessoa
              from tr_juiz_pessoa tjp
             where tjp.sq_juiz in
                   (select j.sq_juiz
                      from tb_juiz j
                     where j.in_desembargador <> 'N'));

  cursor cJuizNulo1 is
    select *
      from EGT_INFO_PROCESSO p
     where p.num_remessa = v_Num_Remessa
       and p.num_lote = v_Lote
       and p.num_juiz IS NULL
       and p.num_item in (29,
                          30,
                          31,
                          32,
                          65,
                          62,
                          64,
                          39,
                          40,
                          41,
                          42,
                          43,
                          44,
                          46,
                          47,
                          48,
                          49,
                          50,
                          55,
                          35,
                          36,
                          68,
                          319,
                          319,
                          74,
                          75,
                          93,
                          94,
                          95,
                          96,
                          114,
                          115,
                          118,
                          121,
                          122,
                          125,
                          128,
                          129,
                          132,
                          142,
                          143,
                          145,
                          148,
                          149,
                          151,
                          154,
                          155,
                          157,
                          160,
                          161,
                          163,
                          166,
                          167,
                          169,
                          174,
                          175,
                          176,
                          177,
                          173,
                          179,
                          269,
                          270,
                          285,
                          286,
                          287);

  cursor cJuizNulo2 is
    select *
      from EGT_INFO_AUDIENCIA p
     where p.num_remessa = v_Num_Remessa
       and p.num_lote = v_Lote
       and p.num_juiz IS NULL
       and p.num_item in (29,
                          30,
                          31,
                          32,
                          65,
                          62,
                          64,
                          39,
                          40,
                          41,
                          42,
                          43,
                          44,
                          46,
                          47,
                          48,
                          49,
                          50,
                          55,
                          35,
                          36,
                          68,
                          319,
                          319,
                          74,
                          75,
                          93,
                          94,
                          95,
                          96,
                          114,
                          115,
                          118,
                          121,
                          122,
                          125,
                          128,
                          129,
                          132,
                          142,
                          143,
                          145,
                          148,
                          149,
                          151,
                          154,
                          155,
                          157,
                          160,
                          161,
                          163,
                          166,
                          167,
                          169,
                          174,
                          175,
                          176,
                          177,
                          173,
                          179,
                          269,
                          270,
                          285,
                          286,
                          287);

  cursor cSetorInativo1(p_inicio date, p_fim date) is
    select *
      from EGT_REMESSA_LOTE erl
     where erl.num_remessa = v_Num_Remessa
       and erl.num_lote = v_Lote
       and sf_vigencia_setor(erl.num_orgao_estatistica, p_inicio, p_fim) <> 'S';

  cursor cSetorInativo2(p_inicio date, p_fim date) is
    select *
      from EGT_INFO_ITEM p
     where p.num_remessa = v_Num_Remessa
       and p.num_lote = v_Lote
       and sf_vigencia_setor(p.num_orgao_estatistica, p_inicio, p_fim) <> 'S';

  cursor cNumeroProcessoErrado1 is
    select p1.num_interno_processo  sq_proc,
           p1.num_orgao_estatistica org_est,
           oe.txt_unidade,
           p1.num_proc,
           p1.num_dig_proc          digito,
           p1.ano_proc              ano,
           p1.dta_atualizacao,
           p2.nr_processo_atual     nr_proc,
           s.nm_setor
      from egt_processo p1
     inner join tb_processo p2
        on p1.num_interno_processo = p2.sq_processo
     inner join tb_setor s
        on s.sq_setor = p2.sq_setor_julgador
     inner join egt_orgao_unidade oe
        on oe.num_unidade = p1.num_orgao_estatistica
     where p2.nr_processo_atual <>
           (decode(length(p1.num_proc),
                   1,
                   '000000',
                   2,
                   '00000',
                   3,
                   '0000',
                   4,
                   '000',
                   5,
                   '00',
                   6,
                   '0') || p1.num_proc ||
           decode(length(p1.num_dig_proc), 1, '0') || p1.num_dig_proc ||
           p1.ano_proc || p1.num_justica || '01' ||
           decode(length(p1.num_vara), 1, '000', 2, '00', 3, '0') ||
           p1.num_vara)
       and p1.dta_atualizacao =
           (select max(proc.dta_atualizacao)
              from egt_processo proc
             where proc.num_interno_processo = p1.num_interno_processo)
       and p1.ind_exclusao <> 'S';

  cursor cNumeroProcessoErrado2 is
    select p1.num_interno_processo  sq_proc,
           p1.num_orgao_estatistica org_est,
           oe.txt_unidade,
           p1.num_proc,
           p1.num_dig_proc          digito,
           p1.ano_proc              ano,
           p1.dta_atualizacao,
           p2.nr_processo_atual     nr_proc,
           s.nm_setor
      from egt_processo p1
     inner join tb_processo p2
        on p1.num_interno_processo = p2.sq_processo
     inner join tb_setor s
        on s.sq_setor = p2.sq_setor_julgador
     inner join egt_orgao_unidade oe
        on oe.num_unidade = p1.num_orgao_estatistica
     where p1.ano_proc > to_number(to_char(sysdate, 'YYYY'))
       and p1.dta_atualizacao =
           (select max(proc.dta_atualizacao)
              from egt_processo proc
             where proc.num_interno_processo = p1.num_interno_processo)
       and p1.ind_exclusao <> 'S';

  cursor cDuplicidade is
    select p.*
      from EGT_INFO_PROCESSO p
     inner join egt_estrutura_item ei
        on ei.num_item = p.num_item
     where p.num_remessa = v_Num_Remessa
       and p.num_lote = v_Lote
       and p.num_seq_processo > 1
       and p.num_item not between 113 and 169
       and p.num_item not between 191 and 193
       and p.num_item not between 204 and 208
       and p.num_item not between 222 and 232
       and p.num_item not between 354 and 358
       and p.num_item not between 362 and 370
       and ei.ind_item_ajuste = 'N';

  cursor cRemetidosConhec1 is
    select aj.*
      from AJT_SP_PROCS_REMET aj
     where aj.num_remessa = v_Num_Remessa
       and aj.num_lote = v_Lote
       and aj.item_ajt1 = 57
       and not exists
     (select p.num_interno_processo
              from egt_info_processo p
             where p.num_item in (27, 28)
               and p.num_interno_processo = aj.num_interno_processo
               and p.num_orgao_estatistica = aj.num_orgao_destino
               and p.num_remessa = aj.num_remessa
               and p.num_lote = aj.num_lote);

  cursor cRemetidosConhec2 is
    select aj.*
      from AJT_SP_PROCS_REMET aj
     where aj.num_remessa = v_Num_Remessa
       and aj.num_lote = v_Lote
       and aj.item_ajt1 = 57
       and not exists
     (select p.num_interno_processo
              from egt_info_processo p
             where p.num_item = aj.num_item
               and p.num_interno_processo = aj.num_interno_processo
               and p.num_orgao_estatistica = aj.num_orgao_destino
               and p.num_remessa = aj.num_remessa
               and p.num_lote = aj.num_lote);

  cursor cRemetidosExec1 is
    select aj.*
      from AJT_SP_PROCS_REMET aj
     where aj.num_remessa = v_Num_Remessa
       and aj.num_lote = v_Lote
       and aj.num_item = 99
       and not exists
     (select p.num_interno_processo
              from egt_info_processo p
             where p.num_item = 92
               and p.num_interno_processo = aj.num_interno_processo
               and p.num_orgao_estatistica = aj.num_orgao_destino
               and p.num_remessa = aj.num_remessa
               and p.num_lote = aj.num_lote);

  cursor cRemetidosExec2 is
    select aj.*
      from AJT_SP_PROCS_REMET aj
     where aj.num_remessa = v_Num_Remessa
       and aj.num_lote = v_Lote
       and aj.num_item = 99
       and not exists
     (select p.num_interno_processo
              from egt_info_processo p
             where p.num_item = aj.num_item
               and p.num_interno_processo = aj.num_interno_processo
               and p.num_orgao_estatistica = aj.num_orgao_destino
               and p.num_remessa = aj.num_remessa
               and p.num_lote = aj.num_lote);

  cursor cAudiencias1 is
    select P.*
      from egt_info_processo p
     inner join egt_estrutura_item e
        on e.num_item = p.num_item
     where p.num_remessa = v_Num_Remessa
       and p.num_lote = v_Lote
       and e.num_tipo_complemento = 7
       and e.num_instancia = 1
       and not exists
     (select aud.num_interno_processo
              from egt_info_audiencia aud
             where aud.num_interno_processo = p.num_interno_processo
               and aud.num_remessa = p.num_remessa
               and aud.num_lote = p.num_lote
               and aud.num_item = p.num_item);

  cursor cAudiencias2 is
    select P.*
      from egt_info_audiencia p
     inner join egt_estrutura_item e
        on e.num_item = p.num_item
     where p.num_remessa = v_Num_Remessa
       and p.num_lote = v_Lote
       and e.num_tipo_complemento = 7
       and e.num_instancia = 1
       and not exists
     (select aud.num_interno_processo
              from egt_info_processo aud
             where aud.num_interno_processo = p.num_interno_processo
               and aud.num_remessa = p.num_remessa
               and aud.num_lote = p.num_lote
               and aud.num_item = p.num_item);

  cursor cAgravos is
    select *
      from EGT_INFO_PROCESSO p
     INNER JOIN egt_classe_processual CP
        ON CP.NUM_CLASSE = P.NUM_CLASSE
     where p.num_remessa = v_Num_Remessa
       and p.num_lote = v_Lote
       and CP.NUM_CLASSE_CNJ_SUPERIOR = 1209;

  /* cursor cOrgaoOrigem is
  select *
    from egt_info_processo e
   where e.num_remessa = v_Num_Remessa
     and e.num_lote = v_Lote
     and e.num_item in (27, 28, 57, 92, 97, 343, 372)
     and not exists
   (select *
            from tb_setor s
           where s.tp_setor = 'VT'
             and s.in_setor = 'I'
             and s.sq_setor = e.num_orgao_estatistica_origem);*/

  cursor cClasseAnterior is
    select *
      from egt_info_processo e
     where e.num_remessa = v_Num_Remessa
       and e.num_lote = v_Lote
       and e.num_item in (58, 296)
       and e.num_classe_anterior is null;

  cursor cDtEnvioArqProv is
    select *
      from egt_info_processo e
     where e.num_remessa = v_Num_Remessa
       and e.num_lote = v_Lote
       and e.num_item = 103
       and e.dta_evento_inicial is null;

  cursor cPendentesDecisao(p_dt_fim date) is
    select P.*
      from egt_info_processo p
     where p.num_remessa = v_Num_Remessa
       and p.num_lote = v_Lote
       and p.num_item in (60, 61, 62)
       and exists (select d.sq_processo
              from tb_decisao d
             inner join tb_padrao_decisao_processo pd
                on pd.sq_padrao_decisao_processo =
                   d.sq_padrao_decisao_processo
             where d.sq_processo = p.num_interno_processo
               and d.in_situacao_decisao = 'A'
               and pd.in_decisao_final = 'S'
               and pd.in_classificacao_decisao = 'R'
               and pd.in_instancia = 1
               and trunc(d.dt_decisao) < p_dt_fim + 1
               and d.sq_recurso is null);

  cursor cClasseErradaAud is
    select distinct aud.*
      from egt_info_audiencia aud
     inner join egt_info_processo p
        on p.num_interno_processo = aud.num_interno_processo
     where aud.num_remessa = v_Num_Remessa
       and aud.num_lote = v_Lote
       and aud.num_item = p.num_item
       and aud.num_orgao_estatistica = p.num_orgao_estatistica
       and aud.num_remessa = p.num_remessa
       and aud.num_lote = p.num_lote
       and aud.num_classe <> p.num_classe;

  v_inicio date;
  v_fim    date;
  --------------------------------------------------------------------------------

  procedure popula_log(p_erro         varchar2,
                       p_num_item     number,
                       p_num_orgao    number,
                       p_num_processo number,
                       p_msg          varchar2) is
  
  begin
  
    insert into vl_log_pre_validacao
    values
      (v_Num_Remessa,
       v_Lote,
       p_num_item,
       p_num_orgao,
       p_num_processo,
       p_erro,
       p_msg);
  
  end;

  --------------------------------------------------------------------------------
BEGIN
  sp_msg_ajust('Incio SP_EGT_PRE_VALIDACAO' || v_Num_Remessa || '-' || v_Lote);

  delete from vl_log_pre_validacao l
   where l.num_remessa = v_Num_Remessa
     and l.num_lote = v_Lote;
  commit;

  begin
    select t.dt_inicio, t.dt_fim
      into v_inicio, v_fim
      from tb_remessa t
     where t.num_remessa = v_Num_Remessa;
  end;

  sp_msg_ajust('SP_EGT_PRE_VALIDACAO cDesembargadores1');

  FOR C IN cDesembargadores1 LOOP
  
    popula_log('Desembargador informado em EGT_INFO_PROCESSO',
               c.num_item,
               c.num_orgao_estatistica,
               c.num_interno_processo,
               ' Juiz: ' || c.nom_pessoa || ' Nmero: ' || c.num_juiz);
  
  END LOOP;

  sp_msg_ajust('SP_EGT_PRE_VALIDACAO cDesembargadores2');

  FOR C IN cDesembargadores2 LOOP
  
    popula_log('Desembargador informado em EGT_INFO_AUDIENCIA',
               c.num_item,
               c.num_orgao_estatistica,
               c.num_interno_processo,
               ' Juiz: ' || c.nom_pessoa || ' Nmero: ' || c.num_juiz);
  
  END LOOP;

  sp_msg_ajust('SP_EGT_PRE_VALIDACAO cDesembargadores3');

  FOR C IN cDesembargadores3 LOOP
  
    popula_log('Desembargador informado em EGT_INFO_PESSOA',
               c.num_item,
               c.num_orgao_estatistica,
               null,
               ' Pessoa: ' || c.num_pessoa);
  
  END LOOP;

  sp_msg_ajust('SP_EGT_PRE_VALIDACAO cJuizNulo1');

  FOR C IN cJuizNulo1 LOOP
  
    popula_log('Processo informado com JUIZ NULO em EGT_INFO_PROCESSO',
               c.num_item,
               c.num_orgao_estatistica,
               c.num_interno_processo,
               null);
  
  END LOOP;

  sp_msg_ajust('SP_EGT_PRE_VALIDACAO cJuizNulo2');

  FOR C IN cJuizNulo2 LOOP
  
    popula_log('Processo informado com JUIZ NULO em EGT_INFO_AUDIENCIA',
               c.num_item,
               c.num_orgao_estatistica,
               c.num_interno_processo,
               ' Audiencia: ' || C.NUM_AUDIENCIA);
  
  END LOOP;

  sp_msg_ajust('SP_EGT_PRE_VALIDACAO cSetorInativo1');

  FOR C IN cSetorInativo1(v_inicio, v_fim) LOOP
  
    popula_log('Lote criado para Cordeiro/Barra Mansa',
               null,
               c.num_orgao_estatistica,
               null,
               ' Carga: ' || c.dta_carga_remessa || ' Situao: ' ||
               c.cod_situacao_remessa);
  
  END LOOP;

  sp_msg_ajust('SP_EGT_PRE_VALIDACAO cSetorInativo2');

  FOR C IN cSetorInativo2(v_inicio, v_fim) LOOP
  
    popula_log('Item criado para Cordeiro/Barra Mansa em EGT_INFO_ITEM',
               c.num_item,
               c.num_orgao_estatistica,
               null,
               null);
  
  END LOOP;

  sp_msg_ajust('SP_EGT_PRE_VALIDACAO cNumeroProcessoErrado1');

  FOR C IN cNumeroProcessoErrado1 LOOP
  
    popula_log('Processo com numerao errada em EGT_PROCESSO',
               null,
               c.org_est,
               c.sq_proc,
               ' Atualizao: ' || c.dta_atualizacao);
  
  END LOOP;

  sp_msg_ajust('SP_EGT_PRE_VALIDACAO cNumeroProcessoErrado2');

  FOR C IN cNumeroProcessoErrado2 LOOP
  
    popula_log('Processo com ANO errado em EGT_PROCESSO',
               null,
               c.org_est,
               c.sq_proc,
               ' Atualizao: ' || c.dta_atualizacao);
  
  END LOOP;

  sp_msg_ajust('SP_EGT_PRE_VALIDACAO cDuplicidade');

  FOR C IN cDuplicidade LOOP
  
    popula_log('Processo informado mais de uma vez no mesmo item',
               c.num_item,
               c.num_orgao_estatistica,
               c.num_interno_processo,
               ' Seq: ' || c.num_seq_processo);
  
  END LOOP;

  sp_msg_ajust('SP_EGT_PRE_VALIDACAO cRemetidosConhec1');

  FOR C IN cRemetidosConhec1 LOOP
  
    popula_log('Processo remetido no recebido no destino - fase conhecimento',
               c.num_item,
               null,
               c.num_interno_processo,
               ' Origem: ' || c.num_orgao_origem || ' Destino: ' ||
               c.num_orgao_destino);
  
  END LOOP;

  sp_msg_ajust('SP_EGT_PRE_VALIDACAO cRemetidosConhec2');

  FOR C IN cRemetidosConhec2 LOOP
  
    popula_log('Processo remetido no pendente no destino - fase conhecimento',
               c.num_item,
               null,
               c.num_interno_processo,
               ' Origem: ' || c.num_orgao_origem || ' Destino: ' ||
               c.num_orgao_destino);
  
  END LOOP;

  sp_msg_ajust('SP_EGT_PRE_VALIDACAO cRemetidosExec1');

  FOR C IN cRemetidosExec1 LOOP
  
    popula_log('Processo remetido no recebido no destino - fase execuo',
               c.num_item,
               null,
               c.num_interno_processo,
               ' Origem: ' || c.num_orgao_origem || ' Destino: ' ||
               c.num_orgao_destino);
  
  END LOOP;

  sp_msg_ajust('SP_EGT_PRE_VALIDACAO cRemetidosExec2');

  FOR C IN cRemetidosExec2 LOOP
  
    popula_log('Processo remetido no pendente no destino - fase execuo',
               c.num_item,
               null,
               c.num_interno_processo,
               ' Origem: ' || c.num_orgao_origem || ' Destino: ' ||
               c.num_orgao_destino);
  
  END LOOP;

  sp_msg_ajust('SP_EGT_PRE_VALIDACAO cAudiencias1');

  FOR C IN cAudiencias1 LOOP
  
    popula_log('Processo no informado em INFO_AUDIENCIA',
               c.num_item,
               c.num_orgao_estatistica,
               c.num_interno_processo,
               ' Seq: ' || c.num_seq_processo);
  
  END LOOP;

  sp_msg_ajust('SP_EGT_PRE_VALIDACAO cAudiencias2');

  FOR C IN cAudiencias2 LOOP
  
    popula_log('Processo no informado em INFO_PROCESSO',
               c.num_item,
               c.num_orgao_estatistica,
               c.num_interno_processo,
               ' Dt_aud: ' || c.dta_audiencia);
  
  END LOOP;

  sp_msg_ajust('SP_EGT_PRE_VALIDACAO cAgravos');

  FOR C IN cAgravos LOOP
  
    popula_log('Processo de classe AGRAVO informado em INFO_PROCESSO',
               c.num_item,
               c.num_orgao_estatistica,
               c.num_interno_processo,
               ' Classe: ' || c.nom_classe);
  
  END LOOP;

  /*  sp_msg_ajust('SP_EGT_PRE_VALIDACAO cOrgaoOrigem');
  
  FOR C IN cOrgaoOrigem LOOP
  
    popula_log('Processo cujo orgo de origem no  vara nem TRT',
               c.num_item,
               c.num_orgao_estatistica,
               c.num_interno_processo,
               null);
  
  END LOOP;*/

  sp_msg_ajust('SP_EGT_PRE_VALIDACAO cClasseAnterior');

  FOR C IN cClasseAnterior LOOP
  
    popula_log('Processo no item de classe convertida sem num_classe_anterior',
               c.num_item,
               c.num_orgao_estatistica,
               c.num_interno_processo,
               null);
  
  END LOOP;

  sp_msg_ajust('SP_EGT_PRE_VALIDACAO cDtEnvioArqProv');

  FOR C IN cDtEnvioArqProv LOOP
  
    popula_log('Processo enviado ao arquivo provisrio sem data de envio',
               c.num_item,
               c.num_orgao_estatistica,
               c.num_interno_processo,
               null);
  
  END LOOP;

  sp_msg_ajust('SP_EGT_PRE_VALIDACAO cPendentesDecisao');

  FOR C IN cPendentesDecisao(v_fim) LOOP
  
    popula_log('Processo pendente na fase de conhecimento com deciso final ativa',
               c.num_item,
               c.num_orgao_estatistica,
               c.num_interno_processo,
               null);
  
  END LOOP;

  sp_msg_ajust('SP_EGT_PRE_VALIDACAO cClasseErradaAud');

  FOR C IN cClasseErradaAud LOOP
  
    popula_log('Processo com classes diferentes em INFO_PROCESSO e INFO_AUDIENCIA',
               c.num_item,
               c.num_orgao_estatistica,
               c.num_interno_processo,
               null);
  
  END LOOP;

  sp_msg_ajust('Fim SP_EGT_PRE_VALIDACAO');

  commit;

END;
