create table VL_FAMILIA
(
  SQ_FAMILIA   NUMBER(10) not null,
  DESC_FAMILIA VARCHAR2(80) not null
)
;
comment on table VL_FAMILIA
  is 'Representa um grupo de classes processuais';
comment on column VL_FAMILIA.SQ_FAMILIA
  is 'Chave primria da familia de itens de validao';
comment on column VL_FAMILIA.DESC_FAMILIA
  is ' Descrioda familia';
alter table VL_FAMILIA
  add constraint VL_FAMILIA_PK primary key (SQ_FAMILIA);
alter table VL_FAMILIA
  add constraint VL_FAMILIA_UN unique (DESC_FAMILIA);


create table VL_FAMILIA_CLASSE
(
  NUM_CLASSE NUMBER(5) not null,
  SQ_FAMILIA NUMBER(10) not null
)
;
alter table VL_FAMILIA_CLASSE
  add constraint VL_FAMILIA_CLASSE_PK primary key (NUM_CLASSE, SQ_FAMILIA);
alter table VL_FAMILIA_CLASSE
  add constraint VL_FAMILIA_CLASSE_FK foreign key (NUM_CLASSE)
  references EGT_CLASSE_PROCESSUAL (NUM_CLASSE);


create table VL_ITEM
(
  NUM_ITEM          NUMBER(10) not null,
  SQ_FAMILIA_BASE   NUMBER(10) not null,
  SQ_FAMILIA_EXCLUI NUMBER(10)
)
;
comment on column VL_ITEM.NUM_ITEM
  is 'Chave primria da tabela';
comment on column VL_ITEM.SQ_FAMILIA_BASE
  is 'Chave que referencia a familia de classes base para o item de validao';
comment on column VL_ITEM.SQ_FAMILIA_EXCLUI
  is 'Chave que referencia a familia de classes subtrada da familia base';
alter table VL_ITEM
  add constraint VL_ITEM_PK primary key (NUM_ITEM);
alter table VL_ITEM
  add constraint VL_ITEM_SQ_FAMILIA_BASE_FK foreign key (SQ_FAMILIA_BASE)
  references VL_FAMILIA (SQ_FAMILIA) on delete set null;
alter table VL_ITEM
  add constraint VL_ITEM_SQ_FAMILIA_EXCLUI_FK foreign key (SQ_FAMILIA_EXCLUI)
  references VL_FAMILIA (SQ_FAMILIA) on delete set null;



create table VL_REGRAS_NAO_TEMP
(
  NUM_REGRA  NUMBER not null,
  OPERADOR   VARCHAR2(20) not null,
  TP_REGRA   VARCHAR2(3) not null,
  DESC_REGRA VARCHAR2(500)
)
;
comment on column VL_REGRAS_NAO_TEMP.TP_REGRA
  is 'RC conjuntos, RNT no temporria, RT temporria';
alter table VL_REGRAS_NAO_TEMP
  add constraint VL_REGRAS_NAO_TEMP_PK primary key (NUM_REGRA);
alter table VL_REGRAS_NAO_TEMP
  add constraint OPER
  check (OPERADOR IN ('QT_IGUAL', 'QT_MENOR_IGUAL', 'QT_MAIOR_IGUAL', 'SC_IGUAL','SC_CONTIDO', 'SC_IGUAL_RITO_COM','SC_IGUAL_RITO_SUM', 'TEMPORARIA', 'QV_1', 'QV_1_2', 'QV_1_SC', 'QV_1_2_SC', 'SC_IGUAL_SC','SC_CONTIDO_SC'));
alter table VL_REGRAS_NAO_TEMP
  add constraint REGRA
  check (tp_regra in ('Q', 'C', 'QV'));



create table VL_ITENS_NAO_TEMP_A
(
  NUM_REGRA NUMBER not null,
  NUM_ITEM  NUMBER not null
)
;
alter table VL_ITENS_NAO_TEMP_A
  add constraint VL_IT_NAO_TEMP_A_PK primary key (NUM_REGRA, NUM_ITEM);
alter table VL_ITENS_NAO_TEMP_A
  add constraint VL_IT_NAO_TEMP_A_FK foreign key (NUM_REGRA)
  references VL_REGRAS_NAO_TEMP (NUM_REGRA);



create table VL_ITENS_NAO_TEMP_B
(
  NUM_REGRA NUMBER not null,
  NUM_ITEM  NUMBER not null
)
;
alter table VL_ITENS_NAO_TEMP_B
  add constraint VL_IT_NAO_TEMP_B_PK primary key (NUM_REGRA, NUM_ITEM);
alter table VL_ITENS_NAO_TEMP_B
  add constraint VL_IT_NAO_TEMP_B_FK foreign key (NUM_REGRA)
  references VL_REGRAS_NAO_TEMP (NUM_REGRA);



create table VL_REGRAS_TEMP
(
  NUM_REGRA  NUMBER,
  DESC_REGRA VARCHAR2(200)
)
;
alter table VL_REGRAS_TEMP
  add constraint VL_REGRAS_TEMP primary key (NUM_REGRA);



create table VL_ITENS_TEMP
(
  NUM_REGRA NUMBER not null,
  TP_ITEM   VARCHAR2(1) not null,
  NUM_ITEM  NUMBER not null
)
;
alter table VL_ITENS_TEMP
  add constraint VL_ITENS_TEMP_PK primary key (NUM_REGRA, NUM_ITEM);
alter table VL_ITENS_TEMP
  add constraint VL_ITENS_TEMP_FK foreign key (NUM_REGRA)
  references VL_REGRAS_TEMP (NUM_REGRA);




create table VL_LOG
(
  SQ_SETOR     NUMBER,
  NUM_REGRA    NUMBER,
  DESC_REGRA   VARCHAR2(500),
  MSG          VARCHAR2(500),
  IN_VALIDACAO VARCHAR2(10),
  TP_REGRA     VARCHAR2(5),
  NUM_REMESSA  NUMBER(10) not null,
  NUM_LOTE     NUMBER(2) not null
)
;
comment on column VL_LOG.NUM_REMESSA
  is 'Nmero da Remessa';
comment on column VL_LOG.NUM_LOTE
  is 'Nmero do lote de uma remessa, iniciando de 1 para uma mesma remessa. Utilizado caso ocorra a necessidade de envio de um novo movimento para sobreposio de uma remessa anterior (acerto de uma remessa enviada com erros)';


create table VL_LOG_DETALHADO
(
  SQ_SETOR             NUMBER,
  NUM_REGRA            NUMBER,
  NUM_INTERNO_PROCESSO NUMBER,
  DESC_ERRO            VARCHAR2(100),
  NUM_REMESSA          NUMBER(10) not null,
  NUM_LOTE             NUMBER(2) not null
)
;
comment on column VL_LOG_DETALHADO.NUM_REMESSA
  is 'Nmero da Remessa';
comment on column VL_LOG_DETALHADO.NUM_LOTE
  is 'Nmero do lote de uma remessa, iniciando de 1 para uma mesma remessa. Utilizado caso ocorra a necessidade de envio de um novo movimento para sobreposio de uma remessa anterior (acerto de uma remessa enviada com erros)';


create table VL_PROCESSOS_CONJ_A
(
  NUM_INTERNO_PROCESSO NUMBER(10) not null,
  NUM_CLASSE           NUMBER,
  NUM_ITEM             NUMBER(6) not null
)
;
comment on column VL_PROCESSOS_CONJ_A.NUM_ITEM
  is 'Nmero do Item referente  informao estatstica.  um nmero seqencial gerado atravs de sequence.';


create table VL_PROCESSOS_CONJ_B
(
  NUM_INTERNO_PROCESSO NUMBER(10) not null,
  NUM_CLASSE           NUMBER,
  NUM_ITEM             NUMBER(6) not null
)
;
comment on column VL_PROCESSOS_CONJ_B.NUM_ITEM
  is 'Nmero do Item referente  informao estatstica.  um nmero seqencial gerado atravs de sequence.';



create table VL_TEMP_CLASSES
(
  NUM_CLASSE NUMBER not null
)
;







