CREATE OR REPLACE PROCEDURE "SP_VALIDA_DATAS" (p_num_remessa number,
                                            p_num_lote number,
                                            p_sq_setor number) is
/*
Autor: Jose Carlos
Objetivo: Valida a "regra 2.2 - Datas"
          1) Funcionamento das Vara do Trabalho
             A data de exerccio final de magistrado, quando informada, deve ser maior ou igual a data de exerccio inicial.
             Cada magistrado deve ter pelo menos uma data ativa.
             No  permitido informar 2 perodos de exerccio sobrepostos para o mesmo magistrado.


          2) Audincias
             2.1)A data de realizao da audincia deve ser maior ou igual a data de referncia inicial
             e menor ou igual a data de referncia final.
             2.2)A contagem de registros de data de realizao da audincia deve ser igual ao quantitativo informado

          3) Prazos Medios
             3.1) A data final do evento deve ser maior ou igual a data inicial do evento; a data final do evento deve ser menor ou igual a data final da referncia.
             3.2) Deve ser informada a data inicial do evento para todos os processos do item.
             3.3) Deve ser informada a data final do evento para todos os processos do item.
             3.4) A mdia aritmtica dos dias decorridos entre as datas finais e iniciais deve ser igual ao valor informado.

          4) A data de arquivamento provisrio deve ser menor ou igual a data final do perodo de referncia. (item 103)

*/

cursor cArquivamento is
       select ip.num_interno_processo, ip.dta_evento_inicial, ip.num_item, ip.num_orgao_estatistica
       from egt_info_processo ip
       where ip.num_remessa = p_num_remessa
             and ip.num_lote = p_num_lote
             and ip.num_item = 103
             and ip.num_orgao_estatistica = p_sq_setor;

cursor cPrazoProcesso is
      select ip.dta_evento_inicial,
             ip.dta_evento_final,
             ip.num_item,
             ip.num_orgao_estatistica,
             ip.num_interno_processo
      from egt_info_processo ip
      where ip.num_remessa = p_num_remessa
            and ip.num_lote = p_num_lote
            and ip.num_orgao_estatistica = p_sq_setor
            and ip.num_item in (263,264,265,266,267,268,269,270,271,272,359,371,274,305,
                                275,277,308,309,282,307,310,281,306,311,283,284,278,
                                285,279,286,280,287);

cursor cPrazoItem is
      select ii.num_orgao_estatistica, ii.num_item, ii.num_quantidade_item, ii.num_valor_item
      from egt_info_item ii
      where ii.num_remessa = p_num_remessa
            and ii.num_lote = p_num_lote
            and ii.num_orgao_estatistica = p_sq_setor
            and ii.num_item in (263,264,265,266,267,268,269,270,271,272,359,371,274,305,
                                275,277,308,309,282,307,310,281,306,311,283,284,278,
                                285,279,286,280,287);


cursor cAudiencia is
       select ia.dta_audiencia,
              ia.num_item,
              ia.num_orgao_estatistica,
              ia.num_audiencia,
              ia.num_interno_processo
       from egt_info_audiencia ia
       where ia.num_remessa = p_num_remessa
             and ia.num_lote = p_num_lote
             and ia.num_orgao_estatistica = p_sq_setor
             and ia.num_item in (174, 175, 176, 177,173,179);

cursor cItensAudiencia is
       select ii.num_orgao_estatistica, ii.num_item, ii.num_quantidade_item
       from egt_info_item ii
       where ii.num_remessa = p_num_remessa
             and ii.num_lote = p_num_lote
             and ii.num_orgao_estatistica = p_sq_setor
             and ii.num_item in (174, 175, 176, 177,173,179);

cursor cJuizes is
    select distinct i.num_pessoa, i.num_orgao_estatistica
    from egt_info_pessoa i
    where i.num_remessa=p_num_remessa
          and i.num_lote=p_num_lote
          and i.num_orgao_estatistica = p_sq_setor
          and i.num_item in (5,6);

cursor cExercicio(p_dt_inicial_pa date,
                  p_dt_final_pa date,
                  p_num_magistrado number) is
    select m.dta_inicio_vigencia, m.dta_fim_vigencia
    from egt_orgao_hist_mag m
    where m.num_magistrado = p_num_magistrado
          and m.num_orgao_estatistica = p_sq_setor
          and m.dta_inicio_vigencia between p_dt_inicial_pa and p_dt_final_pa
    order by m.dta_inicio_vigencia;

v_dt_final_pa date;
v_dt_inicial_pa date;
v_fim_ant date;
v_inicio_ant date;
v_qt_item number(9);
v_vr_item number(16,2);
v_count_vigens number; --numero de vigencias no periodo

--------------------------------------------------------------------------------------
procedure popula_log(p_num_regra number,
                     p_desc_regra vl_regras_temp.desc_regra%type,
                     p_sq_setor number,
                     p_msg vl_log.msg%type) is

begin
  insert into vl_log values (p_sq_setor,
                             p_num_regra,
                             p_desc_regra,
                             p_msg,
                             'Erro',
                             'DATAS',
                             p_num_remessa,
                             p_num_lote);
  commit;
end;
----------------------------------------------------------------------------------------

begin
    --recupera as datas iniciais e finais do periodo de apurao
    begin
        select distinct e.dta_inicio_periodo_referencia, e.dta_fim_periodo_referencia
        into v_dt_inicial_pa, v_dt_final_pa
        from egt_remessa_lote e
        where e.num_remessa = p_num_remessa
              and e.num_lote = (select max(e2.num_lote) --pega o ultimo lote
                                from egt_remessa_lote e2 
                                where e2.num_remessa = e.num_remessa);
              --and e.num_lote = p_num_lote -- pega o lote passado como parametro
    exception when NO_DATA_FOUND then
        v_dt_inicial_pa:= '01/01/1000';
    end;
        
    if v_dt_inicial_pa != '01/01/1000' then

        --valida datas das audiencias
        --2.1)
        for a in cAudiencia loop
            if not (a.dta_audiencia >= v_dt_inicial_pa and a.dta_audiencia <= v_dt_final_pa) then
                popula_log(301,
                           'Regra de datas: Data da audincia fora do perodo de apurao.',
                           a.num_orgao_estatistica,
                           ' Remessa: ' || p_num_remessa ||
                           ' Lote: ' || p_num_lote ||
                           ' Item: ' || a.num_item ||
                           ' Nmero da audincia: ' || a.num_audiencia ||
                           ' Data da audincia: ' || a.dta_audiencia ||
                           ' Numero do processo: ' || a.num_interno_processo);
            end if;
        end loop;

        --2.2)
        for i in cItensAudiencia loop
            begin
                select count(*)
                into v_qt_item
                from egt_info_audiencia ia
                where ia.num_remessa = p_num_remessa
                      and ia.num_lote = p_num_lote
                      and ia.num_orgao_estatistica = i.num_orgao_estatistica
                      and ia.num_item = i.num_item
                      and ia.dta_audiencia is not null;
            exception when others then
                 v_qt_item:=0;
            end;

            if i.num_quantidade_item != v_qt_item then
                popula_log(302,
                           'Regra de datas: A contagem de registros de data de realizao da audincia deve ser igual ao quantitativo informado.',
                           i.num_orgao_estatistica,
                           ' Remessa: ' || p_num_remessa ||
                           ' Lote: ' || p_num_lote ||
                           ' Item: ' || i.num_item);
            end if;

        end loop;

        --valida datas dos prazos
        for p in cPrazoProcesso loop
            --3.2)
            if p.dta_evento_inicial is null then
                popula_log(305,
                           'Regra de datas: Deve ser informada a data inicial do evento para todos os processos do item.',
                           p.num_orgao_estatistica,
                           ' Remessa: ' || p_num_remessa ||
                           ' Lote: ' || p_num_lote ||
                           ' Item: ' || p.num_item ||
                           ' Numero do processo: ' || p.num_interno_processo);

            end if;

            --3.3)
            if p.dta_evento_final is null then
                popula_log(306,
                           'Regra de datas: Deve ser informada a data final do evento para todos os processos do item.',
                           p.num_orgao_estatistica,
                           ' Remessa: ' || p_num_remessa ||
                           ' Lote: ' || p_num_lote ||
                           ' Item: ' || p.num_item ||
                           ' Numero do processo: ' || p.num_interno_processo);

            end if;

            --3.1)
            if not (p.dta_evento_final >= p.dta_evento_inicial) then
                popula_log(303,
                           'Regra de datas: A data final do evento deve ser maior ou igual a data inicial do evento',
                           p.num_orgao_estatistica,
                           ' Remessa: ' || p_num_remessa ||
                           ' Lote: ' || p_num_lote ||
                           ' Item: ' || p.num_item ||
                           ' Data inicial: ' || p.dta_evento_inicial ||
                           ' Data final: ' || p.dta_evento_final ||
                           ' Numero do processo: ' || p.num_interno_processo);
            end if;

            if not (p.dta_evento_final <= v_dt_final_pa) then
                popula_log(304,
                           'Regra de datas: A data final do evento deve ser menor ou igual a data final da referncia',
                           p.num_orgao_estatistica,
                           ' Remessa: ' || p_num_remessa ||
                           ' Lote: ' || p_num_lote ||
                           ' Item: ' || p.num_item ||
                           ' Data inicial: ' || p.dta_evento_inicial ||
                           ' Data final: ' || p.dta_evento_final ||
                           ' Numero do processo: ' || p.num_interno_processo);
            end if;
        end loop;

        for i in cPrazoItem loop
            --3.4)
            begin
                select ROUND(avg(trunc(ip.dta_evento_final) - trunc(ip.dta_evento_inicial)),2)
                into v_vr_item
                from egt_info_processo ip
                where ip.num_remessa = p_num_remessa
                      and ip.num_lote = p_num_lote
                      and ip.num_orgao_estatistica = i.num_orgao_estatistica
                      and ip.num_item = i.num_item;
            exception when others then
                v_vr_item:=0;
            end;

            if i.num_valor_item != v_vr_item then
               popula_log(307,
                          'Regra de datas: A mdia aritmtica dos dias decorridos entre as datas finais e iniciais deve ser igual ao valor informado',
                          i.num_orgao_estatistica,
                          ' Remessa: ' || p_num_remessa ||
                          ' Lote: ' || p_num_lote ||
                          ' Item: ' || i.num_item);
            end if;

        end loop;

        --1)valida as datas de vigncia dos juizes
        for j in cJuizes loop

            v_fim_ant := '01/01/1000'; --uma data final extrema

            for e in cExercicio(v_dt_inicial_pa, v_dt_final_pa, j.num_pessoa)  loop
                if not (e.dta_inicio_vigencia <= e.dta_fim_vigencia) then
                   popula_log(308,
                              'Regra de datas: A data de exerccio final de magistrado, quando informada, deve ser maior ou igual a data de exerccio inicial.',
                              j.num_orgao_estatistica,
                              ' Remessa: ' || p_num_remessa ||
                              ' Lote: ' || p_num_lote ||
                              ' Nmero do magistrado: ' || j.num_pessoa ||
                              ' Data de vigncia inicial: ' || e.dta_inicio_vigencia ||
                              ' Data de vigncia final: ' || e.dta_fim_vigencia);
                end if;

                if not (e.dta_inicio_vigencia > v_fim_ant) then
                    popula_log(309,
                               'Regra de datas: No  permitido informar 2 perodos de exerccio sobrepostos para o mesmo magistrado',
                               j.num_orgao_estatistica,
                               ' Remessa: ' || p_num_remessa ||
                               ' Lote: ' || p_num_lote ||
                               ' Nmero do magistrado: ' || j.num_pessoa ||
                               ' Periodo A: ' || v_inicio_ant || ' a ' || v_fim_ant ||
                               ' Periodo B: ' || e.dta_inicio_vigencia || ' a ' || e.dta_fim_vigencia);
                end if;

                v_inicio_ant := e.dta_inicio_vigencia;
                v_fim_ant := e.dta_fim_vigencia;

            end loop;

            --pega o numero de vigencias para o juiz no periodo de apurao
            select count(*)
            into v_count_vigens
            from egt_orgao_hist_mag m
            where m.num_orgao_estatistica = j.num_orgao_estatistica
                  and m.num_magistrado = j.num_pessoa
                  and ((m.dta_inicio_vigencia >= v_dt_inicial_pa and m.dta_inicio_vigencia < v_dt_final_pa + 1) -- inicio no periodo
                  or (m.dta_fim_vigencia >= v_dt_inicial_pa and m.dta_fim_vigencia < v_dt_final_pa + 1) -- fim no periodo
                  or (m.dta_inicio_vigencia < v_dt_inicial_pa and (m.dta_fim_vigencia is null or m.dta_fim_vigencia >= v_dt_final_pa + 1))); -- sem fim ou fim posterior

            if v_count_vigens = 0 then
                popula_log(312,
                           'Regra de datas: Cada magistrado deve ter pelo menos uma data ativa.',
                           j.num_orgao_estatistica,
                           ' Remessa: ' || p_num_remessa ||
                           ' Lote: ' || p_num_lote ||
                           ' Nmero do magistrado: ' || j.num_pessoa);
            end if;

        end loop;

        --4)
        for a in cArquivamento loop
            if a.dta_evento_inicial is null then
               popula_log(310,
                          'Regra de datas: Data de arquivamento provisrio nula',
                          a.num_orgao_estatistica,
                          ' Remessa: ' || p_num_remessa ||
                          ' Lote: ' || p_num_lote ||
                          ' Item: ' || a.num_item ||
                          ' Numero do processo: ' || a.num_interno_processo);
            elsif trunc(a.dta_evento_inicial) > v_dt_final_pa then
               popula_log(311,
                          'Regra de datas: A data de arquivamento provisrio deve ser menor ou igual a data final do perodo de referncia',
                          a.num_orgao_estatistica,
                          ' Remessa: ' || p_num_remessa ||
                          ' Lote: ' || p_num_lote ||
                          ' Item: ' || a.num_item ||
                          ' Numero do processo: ' || a.num_interno_processo);
            end if;

        end loop;

    end if;

end;
