-------------------------------------------------------
-- Export file for user EG                           --
-- Created by roterdam.junior on 28/9/2012, 16:26:35 --
-------------------------------------------------------


CREATE OR REPLACE PROCEDURE "SP_VL_VALIDA_CLASSES_POR_ITEM" (p_num_remessa number,
                                                 p_num_lote number,
                                                 p_num_item number,
                                                 p_num_orgao_estatistica number) is


  TYPE NumberTable IS TABLE OF NUMBER;
  regras NumberTable := NumberTable();
  -- ---------------------------------------------------------------------
  -- Recupera o conjunto de processos a serem validados
  -- ---------------------------------------------------------------------
  CURSOR cProcesso IS
      SELECT i.num_interno_processo, num_classe
      FROM egt_info_processo i
      INNER JOIN egt_processo p on p.num_interno_processo=i.num_interno_processo
      WHERE num_remessa = p_num_remessa
            AND num_lote = p_num_lote
            AND num_item = p_num_item
            AND i.num_orgao_estatistica = p_num_orgao_estatistica;

  -- ---------------------------------------------------------------------
  -- Recupera o conjunto  classes utilizadas na validao de um
  -- determinado item
  -- ---------------------------------------------------------------------
  CURSOR cRegras IS
         (SELECT DISTINCT cp.num_classe
         FROM egt_classe_processual cp
         INNER JOIN vl_familia_classe fc ON
               cp.num_classe = fc.num_classe
         INNER JOIN vl_familia f ON
               f.sq_familia = fc.sq_familia
         INNER JOIN vl_item i ON
              i.sq_familia_base = f.sq_familia
         WHERE i.num_item = p_num_item)
         MINUS
         (SELECT DISTINCT cp.num_classe
         FROM egt_classe_processual cp
         INNER JOIN vl_familia_classe fc ON
               cp.num_classe = fc.num_classe
         INNER JOIN vl_familia f ON
               f.sq_familia = fc.sq_familia
         INNER JOIN vl_item i ON
              i.sq_familia_exclui = f.sq_familia
         WHERE i.num_item = p_num_item);

--------------------------------------------------------------------------------------
procedure popula_log(p_desc_regra vl_regras_temp.desc_regra%type,
                     p_sq_setor number,                      
                     p_msg vl_log.msg%type,
                     p_num_interno_processo number) is

begin
  insert into vl_log values (p_sq_setor,
                             1000 + p_num_item,
                             p_desc_regra,                               
                             p_msg,
                             'Erro',
                             'CLASS',
                             p_num_remessa,
                             p_num_lote);
  insert into vl_log_detalhado values (p_sq_setor,
                                       1000 + p_num_item,
                                       p_num_interno_processo,
                                       'Item: ' || p_num_item,
                                       p_num_remessa,
                                       p_num_lote);
                                       
  commit;                                                               
end;
----------------------------------------------------------------------------------------

BEGIN
    OPEN cRegras;
    FETCH cRegras BULK COLLECT INTO regras;
    FOR c IN cProcesso LOOP
      IF NOT c.num_classe MEMBER OF regras THEN
         popula_log('Regra de classes: Processo com classe errada',
                    p_num_orgao_estatistica,
                    ' Remessa: ' || p_num_remessa || 
                    ' Lote: ' || p_num_lote ||  
                    ' Item: ' || p_num_item ||
                    ' Classe: ' || sf_retorna_nome_classe(c.num_classe),
                    c.num_interno_processo);
      END IF;
      
    END LOOP;
    CLOSE cRegras;
END sp_vl_valida_classes_por_item;
